#
# spec file for package zutils
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zutils
Version:        1.12
Release:        bp155.1.4
Summary:        Collection of utilities for dealing with compressed files
License:        GPL-2.0-or-later
Group:          Productivity/Archiving/Compression
URL:            https://www.nongnu.org/zutils/zutils.html
Source0:        https://download.savannah.gnu.org/releases/zutils/zutils-%{version}.tar.lz
Source1:        https://download.savannah.gnu.org/releases/zutils/zutils-%{version}.tar.lz.sig
Source2:        %{name}.keyring
# PATCH-FIX-OPENSUSE zutils-1.7-noconflict.patch
Patch1:         zutils-1.7-noconflict.patch
BuildRequires:  gcc-c++
BuildRequires:  lzip

%description
Zutils is a collection of utilities able to deal with any combination
of compressed and uncompressed files transparently. If any given file,
including standard input, is compressed, its decompressed content is
used. Compressed files are decompressed on the fly; no temporary files
are created.
These utilities are not wrapper scripts but safer and more efficient
C++ programs. In particular the "--recursive" option is very efficient
in those utilities supporting it.

%prep
%autosetup -p1

%build
%configure CXXFLAGS="%{optflags}"
%make_build

%install
%make_install

%check
%make_build check

%files
%doc ChangeLog README
%license COPYING
%{_sysconfdir}/zutils.conf
%{_bindir}/*
%{_infodir}/*.info%{?ext_info}
%{_mandir}/man1/*.1%{?ext_man}

%changelog
* Sun Jan 22 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.12:
  * 'zutilsrc' has been renamed to 'zutils.conf', and is loog for in
    $XDG_CONFIG_HOME/zutils.conf instead of $HOME/.zutilsrc.
    (XDG_CONFIG_HOME defaults to $HOME/.config).
  * In zcat, zcmp, zdiff, and zgrep, the option '-O, --force-format'
    now can force also "uncompressed" format.
  * zcmp now accepts the option '-H, --hexadecimal' to print byte
    values in hexadecimal instead of octal.
  * zcmp: option '-s' changed to '--script'
  * zcmp: '-q' has been assigned to options '--quiet' and '--silent'
  * zcmp: '-q' now only suppresses diagnostic messages written to
    stderr
  * zcmp: '-s' now only suppresses messages about file differences
    written to stdout or stderr.
  * zcmp: Option '-l, --list' is now different from option '-v,
  - -verbose', whichnow undoes the effect of '--quiet'.
  * zcmp now prints byte and line in EOF message like GNU cmp:
    "zcmp: EOF on FILE after byte B, in line L".
  * zgrep now also accepts the following options:
    '-G, --basic-regexp',
    '--label=<label>',
    '--line-buffered',
    '-P, --perl-regexp',
    '--silent',
    '-T, --initial-tab',
    '-U, --binary', and
    '-Z, --null'.
  * ztest now exits with status 2 if an uncompressed file has a
    compressed file name extension, or if a compressed file has a
    wrong compressed extension.
  * zudate now accepts option '-d, --destdir' to write recompressed
    files to another directory.
  * zupdate now accepts option '-e, --expand-extensions', which
    makes it expand combined file name extensions; tgz --> tar.lz.
  * zupdate now also accepts option '-i, --ignore-errors', which
    makes it ignore non-fatal errors
  * All utilities now support compress'd (.Z) files through gzip.
  * At verbosity level 1 (2 for zdiff and zgrep) or higher, '-V,
  - -version' now prints the versions of the compressors used
    (limited by option '-M, --format').
  * Diagnostics caused by invalid arguments to command line options
    now show the argument and the name of the option.
* Thu Apr 14 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.11:
  * zcmp.cc, zdiff.cc (main): Fix race returning 1 instead of 2 when a
    compressor is not found or when the wrong format is forced.
  * zcmp.cc (getnum): Show option name and valid range if error.
  * All tools: Show option name if error in option argument.
  * Add support for zstd format to all tools.
  * 'zdiff -v -V' now prints the version of the diff program used.
  * 'zgrep --verbose -V' now prints the version of the grep program used.
  * zutils.texi: Document recompression of read-only files by linking.
  * zutils.texi: Change GNU Texinfo category to 'Compression'.
* Thu Jan 21 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.10:
  * zdiff.cc (set_fifonames): Encode pid in little endian order.
  * zupdate.cc (zupdate_file): Fix a portability issue with Solaris 10.
  * zutils.texi: Document that 'zgrep -L' fails with GNU grep 3.2 to 3.4.
  * check.sh: Test empty input files with all tools except zupdate.
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.9:
  * zcmp.cc zdiff.cc: Read standard input only if requested.
  * zdiff.cc (main): Pass options '-W' and '-y' to diff.
  * zutils.cc (test_format): Detect bzip2 and lzip files better.
  * ztest.cc (main): Continue testing if any input file is a terminal.
  If verbosity >= 1, print number of files that failed the test.
  * zcat.cc zgrep.cc ztest.cc (main): Check return value of close( infd ).
  * zutils.cc (good_status): Ignore trailing data remaining in feeder.
  * zupdate.cc (zupdate_file): Support new and old lzip option '-o'.
  Keep combined extensions: tgz, tbz, tbz2, txz --> tlz.
  Quote file names in zcmp_command to allow file names with spaces.
  * *.cc (main): Set a valid invocation_name even if argc == 0.
  * zutils.texi: Improve descriptions of zcat, zcmp, and zdiff.
* Wed Apr 22 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.8:
  * See provided NEWS for detailed list of changes
- Drop no longer needed patches:
  * zutils-1.7-zcat-buffer-overrun.patch
* Sat Aug 25 2018 aloisio@gmx.com
- Added zutils-1.7-noconflict.patch (fixes boo#1105973)
* Mon Aug  6 2018 aloisio@gmx.com
- Added zutils-1.7-zcat-buffer-overrun.patch (fixes boo#1103878)
* Sat Jul 14 2018 antoine.belvire@opensuse.org
- Update to version 1.7:
  * zgrep.cc (main): Pass '--color' option to grep.
  * check.sh: Added new tests for zgrep.
* Mon Feb 19 2018 aloisio@gmx.com
- Update to version 1.6
  * zcmp.cc: Accept 'B' suffix in '--ignore-initial=1kB:1234B'.
  * zutils.cc (feed_data): Show input filename in error messages.
  Version 1.5
  * zupdate.cc (zupdate_file): Pass '-q' to zcmp if verbosity < 0.
  * zcat.cc zgrep.cc ztest.cc (main): Don't use stdin more than
    once.
  * zdiff.cc (set_fifonames): Use '_' if both names are different.
  * configure: Avoid warning on some shells when testing for g++.
  * Makefile.in: Detect the existence of install-info.
  * testsuite/check.sh: A POSIX shell is required to run the
    tests.
* Sun Jan  3 2016 p.drouand@gmail.com
- Update to version 1.4
  * Option '--format' has been renamed to '-O, --force-format'.
  * Added new option '-M, --format=<list>' to all utilities.
* Sat Apr 18 2015 mpluskal@suse.com
- Conflict with gzip
* Sat Apr 18 2015 mpluskal@suse.com
- Initial package for version 1.3
